|Documentation| |Test results| |Test coverage| |Code analysis| |License|
|Analytics|

WC-Onto
=======

Ontology for whole-cell modeling

Installation
------------

Installing the ontology for use in Python
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

1. Install this Python package with pip

   ::

       pip install git+https://github.com/KarrLab/wc_onto.git#egg=wc_onto[all]

   This command will install this Python package, including the ontology
   (in OBO format) and the Python code for using the ontology. Once
   installed, the ontology will be located at
   ``pkg_resources.resource_filename('wc_onto', 'onto.obo')``.

2. Obtain a `BioPortal API key <http://bioportal.bioontology.org/>`__
3. Save your BioPortal API key to a configuration file
   (``~/.wc/wc_onto.cfg``)

   ::

       [wc_onto]
           [[bioportal]]
               key = <BioPortal API key>

4. Import the package. The other ontologies which wc\_onto references
   will automatically be downloaded the first time that the package is
   imported.

   ::

       from wc_onto import onto

Downloading the ontology
~~~~~~~~~~~~~~~~~~~~~~~~

Alternatively, the ontology can be downloaded (in OBO format) from
GitHub or BioPortal

-  Download `latest
   revision <https://raw.githubusercontent.com/KarrLab/wc_onto/master/wc_onto/onto.obo>`__
   from GitHub
-  Download `latest
   snapshot <https://bioportal.bioontology.org/ontologies/WC>`__ from
   BioPortal

Documentation
-------------

Please see the `API documentation <https://docs.karrlab.org/wc_onto>`__.

License
-------

The package is released under the `MIT license <LICENSE>`__.

Development team
----------------

This package was developed by the `Karr Lab <https://www.karrlab.org>`__
at the Icahn School of Medicine at Mount Sinai in New York, USA.

Questions and comments
----------------------

Please contact the `Karr Lab <https://www.karrlab.org>`__ with any
questions or comments.

.. |Documentation| image:: https://readthedocs.org/projects/wc-onto/badge/?version=latest
   :target: https://docs.karrlab.org/wc_onto
.. |Test results| image:: https://circleci.com/gh/KarrLab/wc_onto.svg?style=shield
   :target: https://circleci.com/gh/KarrLab/wc_onto
.. |Test coverage| image:: https://coveralls.io/repos/github/KarrLab/wc_onto/badge.svg
   :target: https://coveralls.io/github/KarrLab/wc_onto
.. |Code analysis| image:: https://api.codeclimate.com/v1/badges/e7b017f281d0905620de/maintainability
   :target: https://codeclimate.com/github/KarrLab/wc_onto
.. |License| image:: https://img.shields.io/github/license/KarrLab/wc_onto.svg
   :target: LICENSE
.. |Analytics| image:: https://ga-beacon.appspot.com/UA-86759801-1/wc_onto/README.md?pixel

